camelot.camelot.model.authentication

Package camelot :: Package camelot :: Package model :: Module authentication |
[hide private]
[frames] | no frames]

# Module authentication

source code

Set of classes to store persons, organizations, relationships and permissions

These structures are modeled like described in 'The Data Model Resource Book' by Len Silverston, Chapter 2

Classes | [hide private]
| PartyRelationship
| EmployerEmployee Relation from employer to employee
| DirectedDirector Relation from a directed organization to a director
| RepresentedRepresentor Relation from a represented party to the director representing the party
| SupplierCustomer Relation from supplier to customer
| SharedShareholder Relation from a shared organization to a shareholder
| Party Base class for persons and organizations.
| Organization An organization represents any internal or external organization.
| Person Person represents natural persons, these can be given access to the system and as such require a username.
| GeographicBoundary
| Country
| City
| Address
| PartyAddressRoleType
| PartyAddress
| ContactMechanism
| PartyContactMechanism

Functions | [hide private]
end_of_times() | source code
getCurrentPerson() Get the currently logged in person | source code
updateLastLogin() Update the last login of the current person to now | source code

Variables | [hide private]
| __metadata__ = `metadata`
| _current_person_ = `None`